==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/chest/dialogs_nl.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("We hebben hem eindelijk gevonden.")


dialogId("tru-m-co", "font_small", "What?")
dialogStr("Wat?")


dialogId("tru-v-poklad", "font_big", "Captain Silver`s treasure, of course.")
dialogStr("De schat van kapitein Silver, natuurlijk.")


dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("De Heilige Graal, natuurlijk!")


dialogId("tru-v-vkupe", "font_big", "It`s neatly in one place: the treasure and the Grail.")
dialogStr("Alles lekker makkelijk op één plek. De schat en de Graal.")


dialogId("tru-m-zrada", "font_small", "I think it`s much too easy to be true.")
dialogStr("Ik geloof er niks van. Het is veel te makkelijk.")


dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Ik denk dat als dit echt ons doel was, dat het spel dat aan de speler zou laten weten.")


dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("Maar, ik heb het aan de speler laten weten. Misschien is dat wel genoeg.")


dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Maar ik heb twijfel gezaaid. Dat zou verwarrend kunnen zijn.")


dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("Hmm, nou ja. WAARSCHIJNLIJK is dit niet dat wat we zoeken.")


dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("Dat is beter. Er is nog wat onzekerheid.")


dialogId("tru-m-truhla0", "font_small", "Couldn`t we close that chest?")
dialogStr("Kunnen we die kist niet dicht doen?")


dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("Zullen we proberen die kist dicht te doen?")


dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Met een gesloten kist zou het veel makkelijker zijn.")


dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Probeer eens tegen het deksel te duwen.")


dialogId("tru-m-vzit0", "font_small", "Won`t we take something with us?")
dialogStr("Zullen we niet iets meenemen?")


dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("Kunnen we niet wat van deze schat meenemen?")


dialogId("tru-m-vzit2", "font_small", "Aren`t you sorry to leave all this treasure behind?")
dialogStr("Vind je het niet jammer om al deze waardevolle dingen hier achter te laten?")


dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("We moeten blij zijn als we hier zelf uit zien te komen.")


dialogId("tru-v-vzit1", "font_big", "Don`t forget our mission.")
dialogStr("Vergeet niet dat we een missie hebben.")


dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("Een schat meeslepen zou toch alleen maar onhandig zijn.")


dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("Al dit geglinster is wel prachtig, zeg.")


dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Hier glimt alles zo. Ik word duizelig.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/chest/dialogs_nl.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("We hebben het ding eindelijk gevonden.")


dialogId("tru-m-co", "font_small", "What?")
dialogStr("Wat?")


dialogId("tru-v-poklad", "font_big", "Captain Silver’s treasure, of course.")
dialogStr("De schat van kapitein Silver, natuurlijk.")


dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("De Heilige Graal, natuurlijk!")


dialogId("tru-v-vkupe", "font_big", "It’s neatly in one place: the treasure and the Grail.")
dialogStr("Alles lekker makkelijk op één plek. De schat en de Graal.")


dialogId("tru-m-zrada", "font_small", "I think it’s much too easy to be true.")
dialogStr("Ik vertrouw het niet helemaal. Het is veel te makkelijk.")


dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Ik denk dat als dit echt ons doel was, dat het spel dat aan de speler zou laten weten.")


dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("Maar, ik heb het aan de speler laten weten. Misschien is dat wel genoeg.")


dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Maar ik heb twijfel gezaaid. Dat zou verwarrend kunnen zijn.")


dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("Hmm, nou ja. WAARSCHIJNLIJK is dit niet wat we zoeken.")


dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("Dat is beter. Er is nog wat onzekerheid.")


dialogId("tru-m-truhla0", "font_small", "Couldn’t we close that chest?")
dialogStr("Kunnen we die kist niet dicht doen?")


dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("Zullen we proberen die kist dicht te doen?")


dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Met een gesloten kist zou het veel makkelijker zijn.")


dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Probeer eens tegen het deksel te duwen.")


dialogId("tru-m-vzit0", "font_small", "Won’t we take something with us?")
dialogStr("Zullen we niet iets meenemen?")


dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("Kunnen we niet wat van deze schat meenemen?")


dialogId("tru-m-vzit2", "font_small", "Aren’t you sorry to leave all this treasure behind?")
dialogStr("Vind je het niet jammer om al deze edelstenen en juwelen hier achter te laten?")


dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("We moeten blij zijn als we hier zelf uit zien te komen.")


dialogId("tru-v-vzit1", "font_big", "Don’t forget our mission.")
dialogStr("Vergeet onze missie niet.")


dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("Een schat meeslepen zou toch alleen maar onhandig zijn.")


dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("Al dit geglinster is wel prachtig, zeg.")


dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Alles glimt hier zo. Ik word duizelig.")
